@@ -2,11 +2,11 @@ import pandas as pd
 
 class CsvOperations:
 
-    def read_csv(filepath):
+    def read_csv(self, filepath):
         df = pd.read_csv(filename)
         print(df.to_string())
         
-    def write_to_csv(filepath):
+    def write_to_csv(self, filepath):
         
         df = pd.DataFrame({'name': ['Raphael', 'Donatello'],
                    'mask': ['red', 'purple'],
